@@ -33,9 +33,10 @@
 #  define KBOOKMARKS_DEPRECATED_NO_EXPORT KBOOKMARKS_NO_EXPORT KBOOKMARKS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KBOOKMARKS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KBOOKMARKS_NO_DEPRECATED
+#    define KBOOKMARKS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
